==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/el-GR/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Επιβεβαιώστε μαζική διαγραφή περιουσιακών στοιχείων',
    'bulk_restore'      => 'Επιβεβαίωση Μαζικής Επαναφοράς Αντικειμένων', 
  'bulk_delete_help'	=> 'Εξετάστε τα περιουσιακά στοιχεία για μαζική διαγραφή παρακάτω. Μόλις διαγραφεί, αυτά τα περιουσιακά στοιχεία μπορούν να αποκατασταθούν, αλλά αυτά δεν θα είναι πλέον συσχετιζόμενα με οποιοσδήποτε χρήστη που τους έχει ανατεθεί.',
  'bulk_restore_help'	=> 'Εξετάστε τα περιουσιακά στοιχεία για μαζική αποκατάσταση παρακάτω. Μόλις αποκατασταθεί, αυτά τα περιουσιακά στοιχεία δεν θα συσχετιστεί με χρήστες στους οποίους είχαν ανατεθεί προηγουμένως.',
  'bulk_delete_warn'	=> 'Πρόκειται να διαγράψετε: asset_count περιουσιακών στοιχείων.',
  'bulk_restore_warn'	=> 'Πρόκειται να επαναφέρετε: asset_count περιουσιακών στοιχείων.',
    'bulk_update'		=> 'Μαζική ενημέρωση παγίων',
    'bulk_update_help'	=> 'Αυτή η φόρμα επιτρέπει την ενημέρωση πολλαπλών παγίων ταυτόχρονα. Μόνο συμπληρώστε τα πεδία που θέλετε να αλλάξετε. Οποιαδήποτε πεδίο αριστερά μείνει κενό θα παραμείνει ως αμετάβλητο. ',
    'bulk_update_warn'	=> 'Πρόκειται να επεξεργαστείτε τις ιδιότητες ενός ενιαίου περιουσιακού στοιχείου."Πρόκειται να επεξεργαστείτε τις ιδιότητες του:asset_count περιουσιακών στοιχείων.',
    'bulk_update_with_custom_field' => 'Σημειώστε ότι τα περιουσιακά στοιχεία είναι: asset_model_count διαφορετικοί τύποι μοντέλων.',
    'bulk_update_model_prefix' => 'Σε Μοντέλα', 
    'bulk_update_custom_field_unique' => 'Αυτό είναι ένα μοναδικό πεδίο και δεν μπορεί να επεξεργαστεί μαζικά.',
    'checkedout_to'		=> 'Ανάθεση σε',
    'checkout_date'		=> 'Ημερομηνία αποχώρησης',
    'checkin_date'		=> 'Ημερομηνία άφιξης',
    'checkout_to'		=> 'Ημερομηνία αποχώρησης σε',
    'cost'				=> 'Κόστος αγοράς',
    'create'			=> 'Δημιουργία παγίου',
    'date'				=> 'Ημερομηνία αγοράς',
    'depreciation'	    => 'Υποτίμηση',
    'depreciates_on'	=> 'Αποσβέσεις σε',
    'default_location'	=> 'Προεπιλεγμένη τοποθεσία',
    'default_location_phone' => 'Προεπιλεγμένο Τηλέφωνο Τοποθεσίας',
    'eol_date'			=> 'EOL ημερομηνία',
    'eol_rate'			=> 'EOL δείκτης',
    'expected_checkin'  => 'Αναμενώμενη ημέρα άφιξης',
    'expires'			=> 'Λήξη',
    'fully_depreciated'	=> 'Έχει πλήρως αποσβεστεί',
    'help_checkout'		=> 'Αν θέλετε να εκχωρήσετε αυτό το πάγιο αμέσως, επιλέξτε «Έτοιμοι να αναπτύξετε» από την παρακάτω λίστα. ',
    'mac_address'		=> 'Διεύθυνση MAC',
    'manufacturer'		=> 'Κατασκευαστής',
    'model'				=> 'Μοντέλο',
    'months'			=> 'μήνες',
    'name'				=> 'Ονομασία του παγίου',
    'notes'				=> 'Σημειώσεις',
    'order'				=> 'Αριθμός παραγγελίας',
    'qr'				=> 'Κωδικός QR',
    'requestable'		=> 'Οι χρήστες μπορούν να αιτηθούν το πάγιο',
    'select_statustype'	=> 'Επιλέξτε Τύπο Κατάστασης',
    'serial'			=> 'Σειριακός',
    'status'			=> 'Κατάσταση',
    'tag'				=> 'Ετικέτα πόρων',
    'update'			=> 'Ενημέρωση παγίου',
    'warranty'			=> 'Εγγύηση',
        'warranty_expires'		=> 'Λήξη Εγγύησης',
    'years'				=> 'έτη',
    'asset_location' => 'Ενημέρωση Θέσης Περιουσιακών Στοιχείων',
    'asset_location_update_default_current' => 'Ενημέρωση προεπιλεγμένης τοποθεσίας ΚΑΙ πραγματικής τοποθεσίας',
    'asset_location_update_default' => 'Ενημέρωση μόνο προεπιλεγμένης τοποθεσίας',
    'asset_location_update_actual' => 'Ενημέρωση μόνο πραγματικής τοποθεσίας',
    'asset_not_deployable' => 'Αυτή η κατάσταση ενεργητικού δεν μπορεί να αναπτυχθεί. Αυτό το στοιχείο δεν μπορεί να ελεγχθεί.',
    'asset_deployable' => 'Αυτή η κατάσταση μπορεί να χρησιμοποιηθεί. Αυτό το στοιχείο μπορεί να ελεγχθεί.',
    'processing_spinner' => 'Επεξεργασία... (Αυτό μπορεί να πάρει λίγο χρόνο σε μεγάλα αρχεία)',
    'optional_infos'  => 'Προαιρετικές Πληροφορίες',
    'order_details'   => 'Σχετικές Πληροφορίες Παραγγελίας'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/el-GR/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Επιβεβαιώστε μαζική διαγραφή περιουσιακών στοιχείων',
    'bulk_restore'      => 'Επιβεβαίωση Μαζικής Επαναφοράς Αντικειμένων', 
  'bulk_delete_help'	=> 'Εξετάστε τα περιουσιακά στοιχεία για μαζική διαγραφή παρακάτω. Μόλις διαγραφεί, αυτά τα περιουσιακά στοιχεία μπορούν να αποκατασταθούν, αλλά αυτά δεν θα είναι πλέον συσχετιζόμενα με οποιοσδήποτε χρήστη που τους έχει ανατεθεί.',
  'bulk_restore_help'	=> 'Εξετάστε τα περιουσιακά στοιχεία για μαζική αποκατάσταση παρακάτω. Μόλις αποκατασταθεί, αυτά τα περιουσιακά στοιχεία δεν θα συσχετιστεί με χρήστες στους οποίους είχαν ανατεθεί προηγουμένως.',
  'bulk_delete_warn'	=> 'Πρόκειται να διαγράψετε: asset_count περιουσιακών στοιχείων.',
  'bulk_restore_warn'	=> 'Πρόκειται να επαναφέρετε: asset_count περιουσιακών στοιχείων.',
    'bulk_update'		=> 'Μαζική ενημέρωση παγίων',
    'bulk_update_help'	=> 'Αυτή η φόρμα επιτρέπει την ενημέρωση πολλαπλών παγίων ταυτόχρονα. Μόνο συμπληρώστε τα πεδία που θέλετε να αλλάξετε. Οποιαδήποτε πεδίο αριστερά μείνει κενό θα παραμείνει ως αμετάβλητο. ',
    'bulk_update_warn'	=> 'Πρόκειται να επεξεργαστείτε τις ιδιότητες ενός ενιαίου περιουσιακού στοιχείου."Πρόκειται να επεξεργαστείτε τις ιδιότητες του:asset_count περιουσιακών στοιχείων.',
    'bulk_update_with_custom_field' => 'Σημειώστε ότι τα περιουσιακά στοιχεία είναι: asset_model_count διαφορετικοί τύποι μοντέλων.',
    'bulk_update_model_prefix' => 'Σε Μοντέλα', 
    'bulk_update_custom_field_unique' => 'Αυτό είναι ένα μοναδικό πεδίο και δεν μπορεί να επεξεργαστεί μαζικά.',
    'checkedout_to'		=> 'Ανάθεση σε',
    'checkout_date'		=> 'Ημερομηνία αποχώρησης',
    'checkin_date'		=> 'Ημερομηνία άφιξης',
    'checkout_to'		=> 'Ημερομηνία αποχώρησης σε',
    'cost'				=> 'Κόστος αγοράς',
    'create'			=> 'Δημιουργία παγίου',
    'date'				=> 'Ημερομηνία αγοράς',
    'depreciation'	    => 'Υποτίμηση',
    'depreciates_on'	=> 'Αποσβέσεις σε',
    'default_location'	=> 'Προεπιλεγμένη τοποθεσία',
    'default_location_phone' => 'Προεπιλεγμένο Τηλέφωνο Τοποθεσίας',
    'eol_date'			=> 'EOL ημερομηνία',
    'eol_rate'			=> 'EOL δείκτης',
    'expected_checkin'  => 'Αναμενώμενη ημέρα άφιξης',
    'expires'			=> 'Λήξη',
    'fully_depreciated'	=> 'Έχει πλήρως αποσβεστεί',
    'help_checkout'		=> 'Αν θέλετε να εκχωρήσετε αυτό το πάγιο αμέσως, επιλέξτε «Έτοιμοι να αναπτύξετε» από την παρακάτω λίστα. ',
    'mac_address'		=> 'Διεύθυνση MAC',
    'manufacturer'		=> 'Κατασκευαστής',
    'model'				=> 'Μοντέλο',
    'months'			=> 'μήνες',
    'name'				=> 'Ονομασία του παγίου',
    'notes'				=> 'Σημειώσεις',
    'order'				=> 'Αριθμός παραγγελίας',
    'qr'				=> 'Κωδικός QR',
    'requestable'		=> 'Οι χρήστες μπορούν να αιτηθούν το πάγιο',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Επιλέξτε Τύπο Κατάστασης',
    'serial'			=> 'Σειριακός',
    'status'			=> 'Κατάσταση',
    'tag'				=> 'Ετικέτα πόρων',
    'update'			=> 'Ενημέρωση παγίου',
    'warranty'			=> 'Εγγύηση',
        'warranty_expires'		=> 'Λήξη Εγγύησης',
    'years'				=> 'έτη',
    'asset_location' => 'Ενημέρωση Θέσης Περιουσιακών Στοιχείων',
    'asset_location_update_default_current' => 'Ενημέρωση προεπιλεγμένης τοποθεσίας ΚΑΙ πραγματικής τοποθεσίας',
    'asset_location_update_default' => 'Ενημέρωση μόνο προεπιλεγμένης τοποθεσίας',
    'asset_location_update_actual' => 'Ενημέρωση μόνο πραγματικής τοποθεσίας',
    'asset_not_deployable' => 'Αυτή η κατάσταση ενεργητικού δεν μπορεί να αναπτυχθεί. Αυτό το στοιχείο δεν μπορεί να ελεγχθεί.',
    'asset_deployable' => 'Αυτή η κατάσταση μπορεί να χρησιμοποιηθεί. Αυτό το στοιχείο μπορεί να ελεγχθεί.',
    'processing_spinner' => 'Επεξεργασία... (Αυτό μπορεί να πάρει λίγο χρόνο σε μεγάλα αρχεία)',
    'optional_infos'  => 'Προαιρετικές Πληροφορίες',
    'order_details'   => 'Σχετικές Πληροφορίες Παραγγελίας'
];
